<?php

use CRM_Simpleorders_ExtensionUtil as E;

class CRM_Simpleorders_BAO_SoOrder extends CRM_Simpleorders_DAO_SoOrder {

  /**
   * Method to get SoOrder with Order Contacts
   *
   * @param int $soOrderId
   * @return array
   */
  public function getSoOrderWithOrderContacts(int $soOrderId): array {
    $soOrderData = [];
    try {
      $soOrder = \Civi\Api4\SoOrder::get(FALSE)
        ->addSelect('*', 'campaign_id.title', 'state_id.name', 'country_id.name')
        ->addWhere('id', '=', $soOrderId)
        ->execute()->first();
      if (isset($soOrder['id'])) {
        $soOrderData = $soOrder;
        $soOrderContacts = \Civi\Api4\SoOrderContact::get(FALSE)
          ->addWhere('order_id', '=', $soOrderId)
          ->execute();
        foreach ($soOrderContacts as $soOrderContact) {
          $soOrderData[$soOrderContact['role']] = $soOrderContact['contact_id'];
        }
      }
    }
    catch (\CRM_Core_Exception $ex) {
    }
    return $soOrderData;
  }
  public function createSoOrder(array $soOrderValues): ?int {
    $soOrderId = NULL;
    $apiValues = $this->setApiValues($soOrderValues);
    try {
      $soOrder = \Civi\Api4\SoOrder::create(FALSE)
        ->setValues($apiValues)->execute()->first();
      if (isset($soOrder['id'])) {
        $soOrderId = $soOrder['id'];
        $soOrderContact = new CRM_Simpleorders_BAO_SoOrderContact();
        $soOrderContact->addSoOrderContactsFromOrder($soOrderId, $soOrderValues);
      }
    }
    catch (\CRM_Core_Exception $ex) {
    }
    return $soOrderId;
  }
  public function updateSoOrder(int $soOrderId, array $soOrderValues): void {
    $apiValues = $this->setApiValues($soOrderValues);
    try {
      $soOrder = \Civi\Api4\SoOrder::update(FALSE)
        ->addWhere('id', '=', $soOrderId)
        ->setValues($apiValues)->execute()->first();
      if (isset($soOrder['id'])) {
        $soOrderId = $soOrder['id'];
        $soOrderContact = new CRM_Simpleorders_BAO_SoOrderContact();
        $soOrderContact->addSoOrderContactsFromOrder($soOrderId, $soOrderValues);
      }
    }
    catch (\CRM_Core_Exception $ex) {
    }
  }

  /**
   * Method to set the api values to create an order
   *
   * @param array $soOrderValues
   * @return array
   */
  private function setApiValues(array $soOrderValues): array {
    $apiValues = [];
    try {
      $soOrderFields = \Civi\Api4\SoOrder::getFields(FALSE)
        ->addWhere('name', '!=', 'id')
        ->execute();
      foreach ($soOrderFields as $soOrderField) {
        if (isset($soOrderValues[$soOrderField['name']])) {
          $apiValues[$soOrderField['name']] = $soOrderValues[$soOrderField['name']];
        }
      }
    }
    catch (\CRM_Core_Exception $ex) {
    }
    return $apiValues;
  }

}
