<?php

use CRM_Simpleorders_ExtensionUtil as E;

class CRM_Simpleorders_BAO_SoOrderContact extends CRM_Simpleorders_DAO_SoOrderContact {

  /**
   * Method to count the number of orders for a contact
   * @param int $contactId
   * @return int
   */
  public function countContactOrders(int $contactId): int {
    $noOfOrders = 0;
    try {
      $noOfOrders = \Civi\Api4\SoOrderContact::get(FALSE)
        ->addWhere('contact_id', '=', $contactId)
        ->execute()->count();
    }
    catch (\CRM_Core_Exception $ex) {
    }
    return $noOfOrders;
  }

  /**
   * Method to process the contacts from the order values from the order form
   *
   * @param int $soOrderId
   * @param array $soOrderValues
   * @return void
   */
  public function addSoOrderContactsFromOrder(int $soOrderId, array $soOrderValues): void {
    $service = simpleorders_get_service();
    $firstContact = $service->getFirstContactName() . "_contact_id";
    if (isset($soOrderValues[$firstContact])) {
      $this->createSoOrderContact($soOrderId, $service->getFirstContactName(), $soOrderValues[$firstContact]);
    }
    $secondContact = $service->getSecondContactName() . "_contact_id";
    if (isset($soOrderValues[$secondContact])) {
      $this->createSoOrderContact($soOrderId, $service->getSecondContactName(), $soOrderValues[$secondContact]);
    }
  }

  /**
   * Method to add so order contact
   *
   * @param int $soOrderId
   * @param string $role
   * @param int $contactId
   * @return void
   */
  public function createSoOrderContact(int $soOrderId, string $role, int $contactId): void {
    if (!$this->isExistingSoOrderContact($soOrderId, $contactId)) {
      try {
        \Civi\Api4\SoOrderContact::create(FALSE)
          ->addValue('contact_id', $contactId)
          ->addValue('role', $role)
          ->addValue('order_id', $soOrderId)
          ->execute();
      }
      catch (\CRM_Core_Exception $e) {
      }
    }
  }

  /**
   * Method to check if order contact already exists
   *
   * @param int $soOrderId
   * @param int $contactId
   * @return bool
   */
  public function isExistingSoOrderContact(int $soOrderId, int $contactId): bool {
    $exists = FALSE;
    try {
      $count = \Civi\Api4\SoOrderContact::get(FALSE)
        ->addWhere('contact_id', '=', $contactId)
        ->addWhere('order_id', '=', $soOrderId)
        ->execute()->count();
      if ($count > 0) {
        $exists = TRUE;
      }
    }
    catch (\CRM_Core_Exception $ex) {
    }
    return $exists;
  }

  /**
   * Method to get contacts on the order
   *
   * @param int $soOrderId
   * @return array
   */
  public function getContactsOnOrder(int $soOrderId): array {
    $contacts = [];
    try {
      $soOrderContacts = \Civi\Api4\SoOrderContact::get(FALSE)
        ->addWhere('order_id', '=', $soOrderId)
        ->execute();
      foreach ($soOrderContacts as $soOrderContact) {
        $contacts[$soOrderContact['role']] = $soOrderContact['contact_id'];
      }
    }
    catch (\CRM_Core_Exception $ex) {
    }
    return $contacts;
  }

  /**
   *  Method to get the contact role list for the settings form
   *
   * @return array
   */
  public static function getContactRoleList(): array {
    $contactRoleList = [];
    try {
      $optionValues = \Civi\Api4\OptionValue::get(TRUE)
        ->addSelect('value', 'label')
        ->addWhere('option_group_id:name', '=', 'so_contact_role')
        ->addWhere('is_active', '=', TRUE)
        ->execute();
      foreach ($optionValues as $optionValue) {
        $contactRoleList[$optionValue['value']] = $optionValue['label'];
      }
    }
    catch (\CRM_Core_Exception $ex) {
    }
    return $contactRoleList;
  }

}
