<?php

use CRM_Simpleorders_ExtensionUtil as E;

/**
 * Form controller class
 *
 * @see https://docs.civicrm.org/dev/en/latest/framework/quickform/
 */
class CRM_Simpleorders_Form_DelSoOrder extends CRM_Core_Form {
  private int $_soOrderId;
  private array $_currentData = [];

  /**
   * @throws \CRM_Core_Exception
   */
  public function buildQuickForm(): void {
    if ($this->_action == CRM_COre_Action::DELETE) {
      $service = simpleorders_get_service();
      $this->add('hidden', 'so_order_id');
      $this->add('text', 'campaign_id', E::ts("Campaign"), ["readonly" => TRUE]);
      $this->addContactElements();
      $this->add('text', 'order_date', E::ts("Order Date"), ["readonly" => TRUE]);
      $this->add('text', 'delivery_address', E::ts("Delivery Address"), [
        'size' => CRM_Utils_Type::HUGE,
        'readonly' => TRUE]);
      $this->add('text', 'postcode', E::ts("Postcode"), ["readonly" => TRUE]);
      $this->add('text', 'city', E::ts("City"), ["readonly" => TRUE]);
      $this->addStateAndCountry();
      $this->add('text', 'source', E::ts("Source of the Order"), ["readonly" => TRUE]);
      $this->add('text', 'forwarded', E::ts('Order forwarded?'), ["readonly" => TRUE]);
      $this->addButtons([
        ['type' => 'next', 'name' => E::ts('Confirm'), 'isDefault' => TRUE],
        ['type' => 'cancel', 'name' => E::ts('Cancel')],
      ]);
      // export form elements
      $this->assign('elementNames', $service->getRenderableElementNames($this));
    }
    parent::buildQuickForm();
  }

  /**
   * Method to add the state/province and country elements if needed
   *
   * @return void
   */
  private function addStateAndCountry(): void {
    $service = simpleorders_get_service();
    if ($service->usesState()) {
      $this->add('text', 'state_id', E::ts("State/Province"), ["readonly" => TRUE]);
    }
    if ($service->usesCountry()) {
      $this->add('text', 'country_id', E::ts("Country"), ["readonly" => TRUE]);

    }
  }

  /**
   * Method to add the contact elements, based on the names and labels from the
   * settings for the extension
   *
   * @return void
   */
  private function addContactElements(): void {
    $service= simpleorders_get_service();
    $this->add('text', $service->getFirstContactName() . "_contact_id", $service->getFirstContactLabel(), ["readonly" => TRUE]);
    $this->add('text', $service->getSecondContactName() . "_contact_id", $service->getSecondContactLabel(), ["readonly" => TRUE]);
  }

  /**
   * Overridden method to prepare form
   *
   * @return void
   * @throws CRM_Core_Exception
   */
  public function preProcess(): void {
    if ($this->_action == CRM_Core_Action::DELETE) {
      $service = simpleorders_get_service();
      $soOrderId = CRM_Utils_Request::retrieveValue('oid', 'Integer');
      if (!$soOrderId) {
        $soOrderId = $this->getSubmittedValue('so_order_id');
      }
      if ($soOrderId) {
        CRM_Utils_System::setTitle(E::ts("Delete Order ") . $service->getOrderTitleForForm($soOrderId));
        $this->_soOrderId = $soOrderId;
        $soOrder = new CRM_Simpleorders_BAO_SoOrder();
        $this->_currentData = $soOrder->getSoOrderWithOrderContacts($this->_soOrderId);
      }
      $contactId = CRM_Utils_Request::retrieveValue('cid', 'Integer');
      if (!$contactId) {
        CRM_Core_Session::singleton()->pushUserContext(CRM_Utils_System::url('civicrm/contact/view', [
          'reset' => TRUE,
          'force' => TRUE,
          'selectedChild' => 'contact_so_orders',
          'cid' => $contactId]));
      }
    }
  }

  /**
   * Overridden parent method to set defaults
   *
   * @return array
   */
  public function setDefaultValues(): array {
    $defaults = [];
    if ($this->_action == CRM_Core_Action::DELETE) {
      $defaults['so_order_id'] = $this->_soOrderId;
      foreach ($this->_currentData as $currentField => $currentValue) {
        $defaults[$currentField] = $currentValue;
      }
      $service =  simpleorders_get_service();
      $service->setContactDefaults($defaults, $this->_currentData);
    }
    return $defaults;
  }

  /**
   * Overridden parent method to process form submission
   *
   * @return void
   */
  public function postProcess(): void {
    $this->_soOrderId = $this->getSubmittedValue('so_order_id');
    $soOrder = new CRM_Simpleorders_BAO_SoOrder();
    $soOrder->deleteSoOrder($this->_soOrderId);
    parent::postProcess();
  }

}
