<?php

use CRM_Simpleorders_ExtensionUtil as E;

/**
 * Form controller class
 *
 * @see https://docs.civicrm.org/dev/en/latest/framework/quickform/
 */
class CRM_Simpleorders_Form_SoOrderItem extends CRM_Core_Form {
  private int $_soOrderId;
  private int $_soOrderItemId;
  private array $_currentData = [];


  /**
   * @throws \CRM_Core_Exception
   */
  public function buildQuickForm(): void {
    $service = simpleorders_get_service();
    $this->add('hidden', 'so_order_id');
    $this->add('hidden', 'so_order_item_id');
    $soItem = new CRM_Simpleorders_BAO_SoItem();
    if ($this->_action == CRM_Core_Action::ADD) {
      $this->add('select', 'item_id', E::ts('Item'), $soItem->getItemList(), TRUE);
    }
    else {
      $this->add('text', 'item_id', E::ts('Item'), ['readonly' => TRUE]);
    }
    $this->add('text', 'quantity', E::ts("Quantity"), [], TRUE);
    $this->addRule('quantity', E::ts("You can only enter numbers"), 'numeric');
    $this->addRule('quantity',E::ts('You can only enter numbers'),'nopunctuation');
    $this->addButtons([
      ['type' => 'next', 'name' => E::ts('Save'), 'isDefault' => TRUE],
      ['type' => 'cancel', 'name' => E::ts('Cancel')],
    ]);
    // export form elements
    $this->assign('elementNames', $service->getRenderableElementNames($this));
    parent::buildQuickForm();
  }

  /**
   * Overridden method to prepare form
   *
   * @return void
   * @throws CRM_Core_Exception
   */
  public function preProcess(): void {
    $orderId = CRM_Utils_Request::retrieveValue('oid', 'Integer');
    if (!$orderId) {
      $orderId = $this->getSubmittedValue('so_order_id');
    }
    $this->_soOrderId = $orderId;
    if ($this->_action == CRM_Core_Action::UPDATE) {
      CRM_Utils_System::setTitle(E::ts("Update Item on Order ") . $orderId);
      $orderItemId = CRM_Utils_Request::retrieveValue('oiid', 'Integer');
      if (!$orderItemId) {
        $orderItemId = $this->getSubmittedValue('so_order_item_id');
      }
      if ($orderItemId) {
        $this->_soOrderItemId = $orderItemId;
        $soOrderItem = new CRM_Simpleorders_BAO_SoOrderItem();
        $this->_currentData = $soOrderItem->getSoOrderItem($this->_soOrderItemId);
      }
    }
    $this->setFormTitle();
    CRM_Core_Session::singleton()->pushUserContext(CRM_Utils_System::url('civicrm/simpleorders/page/soorderitem', [
      'reset' => TRUE,
      'oid' => $this->_soOrderId]));
  }

  /**
   * Method to set a meaningful title
   * @return void
   */
  private function setFormTitle(): void {
    $service = simpleorders_get_service();
    $soOrderContact = new CRM_Simpleorders_BAO_SoOrderContact();
    $contacts = $soOrderContact->getContactsOnOrder($this->_soOrderId);
    $firstContact = $service->getContactName($contacts[$service->getFirstContactName()]);
    $secondContact = $service->getContactName($contacts[$service->getSecondContactName()]);
    if ($this->_action == CRM_Core_Action::UPDATE) {
      CRM_Utils_System::setTitle(E::ts("Update Item ") . $this->_currentData['item_id.name']
        . E::ts(" on Order ") . $service->getOrderTitleForForm($this->_soOrderId));
    }
    if ($this->_action == CRM_Core_Action::ADD) {
      CRM_Utils_System::setTitle(E::ts("Add Item to Order ")
        . $service->getOrderTitleForForm($this->_soOrderId));
    }
  }
  /**
   * Overridden parent method to set defaults
   *
   * @return array
   */
  public function setDefaultValues(): array {
    $defaults = ['so_order_id' => $this->_soOrderId];
    if ($this->_action == CRM_Core_Action::UPDATE) {
      $defaults['so_order_item_id'] = $this->_soOrderItemId;
      $defaults['quantity'] = $this->_currentData['quantity'];
      $defaults['item_id'] = $this->_currentData['item_id.name'];
    }
    return $defaults;
  }

  /**
   * Overridden parent method to process form submission
   *
   * @return void
   */
  public function postProcess(): void {
    $submitValues = $this->getSubmittedValues();
    if ($submitValues['so_order_item_id']) {
      $this->_soOrderItemId = $submitValues['so_order_item_id'];
    }
    if ($submitValues['so_order_id']) {
      $this->_soOrderId = $submitValues['so_order_id'];
    }
    $soOrderItem = new CRM_Simpleorders_BAO_SoOrderItem();
    if ($this->_action == CRM_Core_Action::ADD) {
      $soOrderItem->createSoOrderItem($submitValues);
      CRM_Core_Session::setStatus(E::ts("Item on Order saved"), E::ts("Saved"), "success");
    }
    if ($this->_action == CRM_Core_Action::UPDATE) {
      $soOrderItem->updateSoOrderItem($this->_soOrderItemId, $submitValues);
    }
    parent::postProcess();
  }

}
