<?php
use CRM_Simpleorders_ExtensionUtil as E;

/**
 * Class showing items on order
 */
class CRM_Simpleorders_Page_SoOrderItem extends CRM_Core_Page {
  private $_soOrderId;

  /**
   * Overridden parent method to run the page
   *
   * @return void
   * @throws CRM_Core_Exception
   */
  public function run() {
    $this->initializePage();
    $this->assign('so_order_items', $this->getOrderItems());
    parent::run();
  }

  /**
   * Method to get all order items
   *
   * @return array
   */
  public function getOrderItems(): array {
    $orderItems = [];
    try {
      $soOrderItems = \Civi\Api4\SoOrderItem::get(TRUE)
        ->addSelect('quantity', 'item_id', 'item_id.name', 'item_id.item_type:label')
        ->addWhere('order_id', '=', $this->_soOrderId)
        ->execute();
      foreach ($soOrderItems as $soOrderItem) {
        $orderItems[$soOrderItem['id']] = [
          'item' => $soOrderItem['item_id.name'],
          'item_type' => $soOrderItem['item_id.item_type:label'],
          'quantity' => $soOrderItem['quantity'],
          'actions' => $this->setActionLinks($soOrderItem['id']),
        ];
      }
    }
    catch (CRM_Core_Exception $ex) {
    }
    return $orderItems;
  }

  /**
   * Method to set the action links
   *
   * @param int $orderItemId
   * @return array
   */
  private function setActionLinks(int $orderItemId): array {
    $deleteUrl = CRM_Utils_System::url('civicrm/simpleorders/form/delsoorderitem', [
      'reset' => TRUE,
      'action' => 'delete',
      'oiid' => $orderItemId,
      'oid' => $this->_soOrderId,
    ],
    );
    $editUrl = CRM_Utils_System::url('civicrm/simpleorders/form/soorderitem', [
      'reset' => TRUE,
      'action' => 'update',
      'oiid' => $orderItemId,
      'oid' => $this->_soOrderId,
    ]);
    return [
      '<a class="action-item" title="Edit" href="' . $editUrl . '">' . E::ts('Edit') . '</a>',
      '<a class="action-item" title="Remove" href="' . $deleteUrl . '">' . E::ts('Remove') . '</a>',
    ];
  }

  /**
   * Initialize the page
   *
   * @return void
   * @throws CRM_Core_Exception
   */
  private function initializePage(): void {
    $this->_soOrderId = CRM_Utils_Request::retrieveValue('oid', 'Integer');
    if (!$this->_soOrderId) {
      throw new Exception(E::ts("No order ID found to show items for"));
    }
    $this->assign('new_order_item_url', CRM_Utils_System::url('civicrm/simpleorders/form/soorderitem', [
      'reset' => TRUE,
      'action' => 'add',
      'oid' => $this->_soOrderId,
    ]));
    CRM_Utils_System::setTitle(E::ts("Items on Order ") . $this->_soOrderId);
  }

}
