<?php

/**
 * @author Erik Hommel <erik.hommel@civicoop.org>
 * @license AGPL-3.0
 */
namespace Civi\Simpleorders;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Definition;
use CRM_Simpleorders_ExtensionUtil as E;
class Container implements CompilerPassInterface {

  /**
   * You can modify the container here before it is dumped to PHP code.
   */
  public function process(ContainerBuilder $container): void {
    if ($container->hasDefinition('data_processor_factory')) {
      $factoryDefinition = $container->getDefinition('data_processor_factory');
      $factoryDefinition->addMethodCall('addDataSource', ['soitem', 'Civi\Simpleorders\DataProcessor\SoItem', E::ts('Item (Simple Orders)')]);
    }
    if ($container->hasDefinition('action_provider')) {
      $actionProviderDefinition = $container->getDefinition('action_provider');
      $actionProviderDefinition->addMethodCall('addAction',
        ['add_so_order', 'Civi\Simpleorders\Actions\AddSoOrder', E::ts('Add Order (Simple Orders)'), []]);
    }
    $definition = new Definition('Civi\Simpleorders\Service');
    $definition->setFactory(['Civi\Simpleorders\Service', 'getInstance']);
    $container->setDefinition('simpleorders', $definition);
    $definition->setPublic(TRUE);
    if (method_exists(Definition::class, 'setPrivate')) {
      $definition->setPrivate(FALSE);
    }
  }

}

