<?php
namespace Civi\Simpleorders;
use CRM_Simpleorders_ExtensionUtil as E;

/**
 * Class for Simple Order Option Group Processing
 *
 * @author Erik Hommel (CiviCooP) <erik.hommel@civicoop.org>
 * @license AGPL-3.0
 */
class OptionGroup {

  /**
   * Method to check if option group exists
   *
   * @param string $optionGroupName
   * @return bool
   */
  public function isExistingOptionGroup(string $optionGroupName): bool {
    if ($optionGroupName) {
      try {
        $count = \Civi\Api4\OptionGroup::get(FALSE)
          ->addSelect('id')
          ->addWhere('name', '=', $optionGroupName)
          ->setLimit(1)->execute()->count();
        if ($count > 0) {
          return TRUE;
        }
      }
      catch (\CRM_Core_Exception $ex) {
      }
    }
    return FALSE;
  }

  /**
   * Method to create new option group
   *
   * @param string $optionGroupName
   * @param array $optionGroupData
   * @return void
   */
  public function createOptionGroup(string $optionGroupName, array $optionGroupData): void {
    if ($optionGroupName) {
      if (!$optionGroupData['title']) {
        $optionGroupData['title'] = ucfirst(strtolower(str_replace("_", " ", $optionGroupName)));
      }
      try {
        \Civi\Api4\OptionGroup::create(FALSE)
          ->addValue('name', $optionGroupName)
          ->addValue('title', $optionGroupData['title'])
          ->addValue('data_type', 'String')
          ->addValue('is_reserved', TRUE)
          ->addValue('is_active', TRUE)
          ->execute();
      }
      catch (\CRM_Core_Exception $ex) {
      }
    }
  }

  /**
   * Method to create the option values
   *
   * @param string $optionGroupName
   * @param array $optionValues
   * @return void
   */
  public function createOptionValues(string $optionGroupName, array $optionValues): void {
    if ($optionGroupName && $optionValues) {
      foreach ($optionValues as $optionValueName => $optionValueLabel) {
        if (!$this->isExistingOptionValue($optionGroupName, $optionValueName)) {
          $this->createOptionValue($optionGroupName, $optionValueName, $optionValueLabel);
        }
      }
    }
  }

  /**
   * Method to create option value
   *
   * @param string $optionGroupName
   * @param string $optionValueName
   * @param string $optionValueLabel
   * @return void
   */
  public function createOptionValue(string $optionGroupName, string $optionValueName, string $optionValueLabel): void {
    if ($optionGroupName && $optionValueName) {
      if (!$optionValueLabel) {
        $optionValueLabel = ucfirst(strtolower(str_replace("_", " ", $optionValueName)));
      }
      try {
        \Civi\Api4\OptionValue::create(FALSE)
          ->addValue('option_group_id:name', $optionGroupName)
          ->addValue('label', $optionValueLabel)
          ->addValue('value', $optionValueName)
          ->addValue('name', $optionValueName)
          ->addValue('is_reserved', TRUE)
          ->addValue('is_active', TRUE)
          ->execute();
      }
      catch (\CRM_Core_Exception $ex) {
      }
    }
  }

  /**
   * Method to check if option value in option group exists
   *
   * @param string $optionGroupName
   * @param string $optionValueName
   * @return bool
   */
  public function isExistingOptionValue(string $optionGroupName, string $optionValueName): bool {
    if ($optionGroupName && $optionValueName) {
      try {
        $count = \Civi\Api4\OptionValue::get(FALSE)
          ->addSelect('id')
          ->addWhere('option_group_id:name', '=', $optionGroupName)
          ->addWhere('name', '=', $optionValueName)
          ->setLimit(1)->execute()->count();
        if ($count > 0) {
          return TRUE;
        }
      }
      catch (\CRM_Core_Exception $ex) {
      }
    }
    return FALSE;
  }

}
