<?php

require_once 'simpleorders.civix.php';

use CRM_Simpleorders_ExtensionUtil as E;
use \Symfony\Component\DependencyInjection\ContainerBuilder;


/**
 * Method to get the streetrecruitment service
 *
 * @return Civi\Simpleorders\Service
 */
function simpleorders_get_service(): Civi\Simpleorders\Service {
  return Civi::service('simpleorders');
}

/**
 * Implements hook_civicrm_container().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_container/
 */
function simpleorders_civicrm_container(ContainerBuilder $container) {
  $container->addCompilerPass(new Civi\Simpleorders\Container());
}
/**
 * Implements hook_civicrm_config().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_config/
 */
function simpleorders_civicrm_config(&$config): void {
  Civi::dispatcher()->addListener('hook_civicrm_tabset', ['Civi\Simpleorders\HookHandler', 'processTabSet']);
  _simpleorders_civix_civicrm_config($config);
}

/**
 * Implements hook_civicrm_navigationMenu().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_navigationMenu/
 */
function simpleorders_civicrm_navigationMenu(&$menu) {
  _simpleorders_civix_insert_navigation_menu($menu, '', [
    'label' => E::ts('Simple Orders'),
    'name' => 'simpleorders',
    'url' => '',
    'permission' => 'access civicrm',
    'operator' => 'OR',
    'separator' => 0,
  ]);
  _simpleorders_civix_insert_navigation_menu($menu, 'simpleorders', [
    'label' => E::ts('Settings for Simple Orders'),
    'name' => 'simpleorders_settings',
    'url' => CRM_Utils_System::url('civicrm/admin/setting/simpleorders', ['reset' => TRUE]),
    'permission' => 'administer CiviCRM',
    'operator' => 'OR',
    'separator' => 0,
  ]);
  _simpleorders_civix_insert_navigation_menu($menu, 'simpleorders', [
    'label' => E::ts('Items'),
    'name' => 'soitems',
    'url' => CRM_Utils_System::url('civicrm/simpleorders/itemlist'),
    'permission' => 'access CiviCRM',
    'operator' => 'OR',
    'separator' => 0,
  ]);
  _simpleorders_civix_insert_navigation_menu($menu, 'simpleorders', [
    'label' => E::ts('Add Order'),
    'name' => 'add_so_order',
    'url' => CRM_Utils_System::url('civicrm/simpleorders/form/soorder', [
      'reset' => TRUE,
      'action' => 'add',
    ]),
    'permission' => 'access CiviCRM',
    'operator' => 'OR',
    'separator' => 0,
  ]);
}

/**
 * Implements hook_civicrm_install().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_install
 */
function simpleorders_civicrm_install(): void {
  _simpleorders_civix_civicrm_install();
}

/**
 * Implements hook_civicrm_enable().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_enable
 */
function simpleorders_civicrm_enable(): void {
  _simpleorders_civix_civicrm_enable();
}
